@@ -28,6 +28,7 @@ class MobileCommand(object):
     DEACTIVATE_IME_ENGINE = 'deactivateIMEEngine'
     GET_ACTIVE_IME_ENGINE = 'getActiveEngine'
     TOGGLE_LOCATION_SERVICES = 'toggleLocationServices'
+    LOCATION_IN_VIEW = 'locationInView'
 
     # Appium Commands
     GET_APP_STRINGS = 'getAppStrings'
@@ -54,3 +55,4 @@ class MobileCommand(object):
     START_ACTIVITY = 'startActivity'
     GET_SETTINGS = 'getSettings'
     UPDATE_SETTINGS = 'updateSettings'
+    SET_LOCATION = 'setLocation'
